/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |         (DATASET 0001: PHASE I - FACILITY TELEPHONE INTERVIEW)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03393-0001-statasetup.do)
 |
 **************************************************************************/

set mem 9m  /* Allocating 9 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Services Research Survey (DSRS), 1990, Dataset 0001"

#delimit ;
label define OBS_NUM   -4 "NOT MASTER FACILITY" ;
label define CRP_MO1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "JANUARY" 2 "FEBRUARY"
                       3 "MARCH" 4 "APRIL" 5 "MAY" 6 "JUNE" 7 "JULY"
                       8 "AUGUST" 9 "SEPTEMBER" 10 "OCTOBER" 11 "NOVEMBER"
                       12 "DECEMBER" ;
label define CRP_DA1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define CRP_YR1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define CRP_MO2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "JANUARY" 2 "FEBRUARY"
                       3 "MARCH" 4 "APRIL" 5 "MAY" 6 "JUNE" 7 "JULY"
                       8 "AUGUST" 9 "SEPTEMBER" 10 "OCTOBER" 11 "NOVEMBER"
                       12 "DECEMBER" ;
label define CRP_DA2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define CRP_YR2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define CLENGTH   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define FRP_MO1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "JANUARY" 2 "FEBRUARY"
                       3 "MARCH" 4 "APRIL" 5 "MAY" 6 "JUNE" 7 "JULY"
                       8 "AUGUST" 9 "SEPTEMBER" 10 "OCTOBER" 11 "NOVEMBER"
                       12 "DECEMBER" ;
label define FRP_DA1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define FRP_YR1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define FRP_MO2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "JANUARY" 2 "FEBRUARY"
                       3 "MARCH" 4 "APRIL" 5 "MAY" 6 "JUNE" 7 "JULY"
                       8 "AUGUST" 9 "SEPTEMBER" 10 "OCTOBER" 11 "NOVEMBER"
                       12 "DECEMBER" ;
label define FRP_DA2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define FRP_YR2   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define FLENGTH   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A1_NO     -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A1_UNIT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "MONTHS" 2 "YEARS" ;
label define A2A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A2B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A2C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A2D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A2E       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A3A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A3B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A3C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A3D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A3E       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4E       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A4F       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A5A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define A5B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define HIDD_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define HIDM_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define HIDF_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define RSDD_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define RSDM_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define RSDF_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define OPDD_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define OPDM_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define OPDF_A6   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define ALC_A6    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define CORRFAC   -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define ALCHONLY  -4 "NOT MASTER FACILITY" 0 "NO" 1 "YES" ;
label define SEQ11CNT  -4 "NOT MASTER FACILITY" ;
label define SEQ12CNT  -4 "NOT MASTER FACILITY" ;
label define NUMMOD    -4 "NOT MASTER FACILITY" ;
label define MOD       -4 "NOT MASTER FACILITY"
                       1 "HOSPITAL INPATIENT DRUG DETOX"
                       2 "HOSPITAL INPATIENT DRUG FREE"
                       3 "RESIDENTIAL DRUG DETOX" 4 "RESIDENTIAL DRUG FREE"
                       5 "OUTPATIENT DRUG DETOX"
                       6 "OUTPATIENT DRUG MAINTENANCE"
                       7 "OUTPATIENT DRUG FREE" 8 "ALCOHOL ONLY"
                       9 "COMBINED MODALITY" ;
label define OWN       -9 "UNKNOWN" -4 "NOT MASTER FACILITY"
                       1 "PRIVATE FOR-PROFIT" 2 "PRIVATE NON-PROFIT"
                       3 "STATE OR LOCAL PUBLIC" 4 "FEDERAL PUBLIC"
                       5 "PUBLIC NON-PROFIT - PUBLIC FACILITY" ;
label define ENV       -4 "NOT MASTER FACILITY" 1 "HOSPITAL INPATIENT"
                       2 "RESIDENTIAL" 3 "OUTPATIENT" 8 "ALCOHOL ONLY"
                       9 "COMBINED MODALITY" ;
label define XENV      -4 "NOT MASTER FACILITY" 1 "HOSPITAL INPATIENT"
                       2 "RESIDENTIAL" 3 "OUTPATIENT DRUG DETOX"
                       4 "OUTPATIENT DRUG MAINTENANCE"
                       5 "OUTPATIENT DRUG FREE" 8 "ALCOHOL ONLY"
                       9 "COMBINED MODALITY" ;
label define STRATUM   -4 "NOT MASTER FACILITY"
                       1 "HOSPITAL IN-PATIENT DRUG TREATMENT"
                       2 "RESIDENTIAL DRUG TREATMENT"
                       3 "OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE"
                       4 "OUT-PATIENT DRUG-FREE TREATMENT"
                       5 "ALCOHOL TREATMENT ONLY" 6 "UNKNOWN TREATMENT TYPE" ;
label define REGION    -4 "NOT MASTER FACILITY" 1 "NORTHEAST"
                       2 "NORTH CENTRAL" 3 "SOUTH" 4 "WEST" ;
label define IMPFLAG   -4 "NOT MASTER FACILITY"
                       0 "NO VARIABLES WERE IMPUTED FOR THIS FACILITY"
                       1 "AT LEAST ONE VARIABLE WAS IMPUTED" ;
label define A7_BOX    -4 "NOT MASTER FACILITY" 0 "BLANK, IMPLICITLY ZERO"
                       1 "BOX CHECKED" ;
label define A7A_FT    -8 "DON'T KNOW" -4 "NOT MASTER FACILITY" ;
label define A7A_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7A_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7A_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7B_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7B_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7B_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7B_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7C_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7C_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7C_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7C_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7D_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7D_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7D_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7D_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7E_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7E_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7E_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7E_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7F_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7F_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7F_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7F_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7G_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7G_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7G_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7G_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7H_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7H_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7H_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7H_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7I_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7I_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7I_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7I_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7J_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7J_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7J_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7J_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7K_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7K_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7K_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7K_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7L_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7L_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7L_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7L_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7M_FT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7M_PT    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7M_CON   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A7M_CERT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A8        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A9        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A10       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A11       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B1_BOX    -4 "NOT MASTER FACILITY" 0 "BLANK - IMPLICITLY ZERO"
                       1 "BOX CHECKED" ;
label define HIDDMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define FLAG4_A   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_B   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_C   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_D   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_E   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_F   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_G   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_H   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_I   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_J   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_K   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_L   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_M   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_N   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_O   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG4_P   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define OPDDMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFMCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFFCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFTCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFMACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFFACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY GENDER"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFTACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE"
                       -4 "NOT MASTER FACILITY" ;
label define FLAG5_A   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_B   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_C   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_D   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_E   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_F   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_G   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_H   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_I   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_J   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_K   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG5_L   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define ALCMCAP   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define ALCFCAP   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define ALCTCAP   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define ALCMACT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define ALCFACT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define ALCTACT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ALC TX"
                       -4 "NOT MASTER FACILITY" ;
label define TOTMCAP   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -4 "NOT MASTER FACILITY" ;
label define TOTFCAP   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -4 "NOT MASTER FACILITY" ;
label define TOTALCAP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define TOTMACT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -4 "NOT MASTER FACILITY" ;
label define TOTFACT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - DATA NOT DIFFERENTIATED BY SEX"
                       -4 "NOT MASTER FACILITY" ;
label define TOTALACT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B2        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define B3        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define B4_NO     -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO WAITING PERIOD" ;
label define B4_UNIT   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 0 "NO WAITING PERIOD"
                       1 "DAYS" 2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define B5        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define B6        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO WAIT-LIST" -4 "NOT MASTER FACILITY"
                       1 "YES" 2 "NO" ;
label define B7        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO WAIT-LIST" -4 "NOT MASTER FACILITY"
                       1 "YES" 2 "NO" ;
label define B8        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO WAIT-LIST" -4 "NOT MASTER FACILITY"
                       1 "YES" 2 "NO" ;
label define B9A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO WAIT-LIST" -4 "NOT MASTER FACILITY"
                       1 "YES" 2 "NO" ;
label define B9B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO WAIT-LIST" -4 "NOT MASTER FACILITY"
                       1 "YES" 2 "NO" ;
label define WAITTIME  -5.00 "ROOT VARS MISSING - UNABLE TO CALCULATE"
                       -4.00 "NOT MASTER FACILITY" ;
label define FLAG6_A   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_B   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_C   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_D   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_E   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_F   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_G   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG6_H   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define B10_BOX   -4 "NOT MASTER FACILITY"
                       0 "BLANK, BOX NOT CHECKED; IMPLICITLY ZERO"
                       1 "BOX CHECKED" ;
label define HIDD_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_A    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_B    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_D    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_E    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -5 "INAP - SRV UNIT DOES NOT PROVIDE OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_A   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_B   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_C   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_D   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_E   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST"
                       -4 "NOT MASTER FACILITY" ;
label define B11       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT HAVE WAIT-LIST"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define B12A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12F      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12G      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12H      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12I      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B12J      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "DO NOT TREAT"
                       2 "NO SPECIAL PRIORITY" 3 "SOME PRIORITY" ;
label define B13A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13F      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13G      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13H      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B13I      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B14       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define B15A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B15B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B15C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B15D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B15E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B16       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B17       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B18       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define FLAG9_A   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_B   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_C   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_D   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_E   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_F   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_G   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_H   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_I   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_J   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_K   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_L   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_M   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_N   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_O   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG9_P   -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define B19       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B20A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B20B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B21       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B22       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B23       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B24A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B24B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B24C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B24D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B24E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B25       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 0 "BOX CHECKED, SKIP TO B26"
                       1 "BOX NOT CHECKED" ;
label define B25A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25F      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25G      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B25H      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NO METH CLIENTS OR NO TAKE-HOME"
                       -4 "NOT MASTER FACILITY" ;
label define B26_NO    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B26_UNIT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 1 "WEEKS" 2 "MONTHS"
                       3 "YEARS" ;
label define B27_NO    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define B27_UNIT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 0 "INDEFINATE, NO MAXIMUM"
                       1 "WEEKS" 2 "MONTHS" 3 "YEARS" ;
label define B28A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - NO MAX LENGTH"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define B28B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - NO MAX LENGTH"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define B28C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - NO MAX LENGTH"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define B28D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - NO MAX LENGTH"
                       -5 "INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define FLAG10_A  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_B  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_C  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_D  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_E  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_F  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_G  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_H  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_I  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_J  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_K  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG10_L  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define SEQ11     -4 "NOT MASTER FACILITY" ;
label define HIDD_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define HIDF_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define RSDD_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define RSDF_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define OPDD_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define OPDM_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define OPDF_DEM  -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define ALC_DEM   -4 "NOT MASTER FACILITY"
                       0 "NOT CHECKED, IMPLICITLY ZERO" 1 "BOX CHECKED" ;
label define A_WHITE   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A_BLACK   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A_HISP    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A_ASIAN   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A_INDIAN  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define A_OTHER   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_14      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_15      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_18      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_25      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_35      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_45      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define B_65      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define C_EMP     -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define C_NOTEMP  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED" ;
label define DEMXENV2  -4 "NOT MASTER FACILITY" 1 "HOSPITAL INPATIENT"
                       2 "RESIDENTIAL" 3 "OUTPATIENT DRUG DETOX"
                       4 "OUTPATIENT DRUG MAINTENANCE"
                       5 "OUTPATIENT DRUG FREE" 6 "OUTPATIENT COMBINED"
                       8 "ALCOHOL ONLY" 9 "COMBINED DRUG/ALCOHOL"
                       10 "COMBINED DRUG ONLY" ;
label define SEQ12     -4 "NOT MASTER FACILITY" ;
label define D_HEROIN  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_CRACK   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_COCAIN  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_BENZ    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_BARB    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_AMPH    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_MARIJ   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_PCP     -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D_OTH     -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define E_NOPAY   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define E_SLFPAY  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define E_PRIVTE  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define E_MEDCD   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define MEDCR_E   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define E_OTHER   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define METHOD    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define C1_BOX    -4 "NOT MASTER FACILITY" 0 "BLANK, IMPLICTLY ZERO"
                       1 "CAN NOT EXCLUDE ALCOHOL ONLY CLIENTS" ;
label define HIDD_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDD_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define FLAG13_A  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_B  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_C  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_D  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_E  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_F  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_G  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_H  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_I  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_J  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_K  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_L  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_M  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_N  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_O  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_P  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_Q  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_R  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_S  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG13_T  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define OPDD_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C1A  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C1B  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C1C  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C1D  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_C1E  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DOES NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define TOT_C1A   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define TOT_C1B   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define TOT_C1C   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define TOT_C1D   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define TOT_C1E   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define C2        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define FLAG14_A  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_B  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_C  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_D  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_E  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_F  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_G  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_H  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_I  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_J  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_K  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_L  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_M  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_N  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_O  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_P  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_Q  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_R  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_S  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG14_T  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define HIDDPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO HIDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO HIDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define HIDDANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO HIDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define HIDDAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO HIDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define HIDFPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO HIDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO HIDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define HIDFANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO HIDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define HIDFAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO HIDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define RSDDPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO RSDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO RSDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define RSDDANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO RSDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define RSDDAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO RSDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define RSDFPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO RSDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO RSDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define RSDFANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO RSDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define RSDFAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO RSDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDDPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDDANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDD PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDDAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDD PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDMPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDM PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDM PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDMANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDM PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDMAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDM PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDFPNO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFPUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define OPDFANO   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - ZERO OPDF PATIENTS"
                       -4 "NOT MASTER FACILITY" ;
label define OPDFAUNT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - ZERO OPDF PATIENTS"
                       -4 "NOT MASTER FACILITY" -1 "BLANK IN SAS" 1 "DAYS"
                       2 "WEEKS" 3 "MONTHS" 4 "YEARS" ;
label define C4        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define C5        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C6        -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" ;
label define C7A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7E       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7F       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7G       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7H       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7I       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C7J       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C8A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C8B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C8C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C8D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C9        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C10_REF   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" ;
label define C11_REF   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C12_TST   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C13       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -6 "INAP - NO PREGNANCY TESTS GIVEN"
                       -5 "INAP - SRV UNIT DID NOT TX PREGNANT FEMALES"
                       -4 "NOT MASTER FACILITY" ;
label define C14       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C16       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C17       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C18A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C18B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C18C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C19A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C19B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C19C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20A_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20A_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20A_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20B_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20B_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20B_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20C_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20C_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20C_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20D_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20D_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20D_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20E_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20E_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20E_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20F_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20F_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20F_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20G_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20G_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20G_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20H_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20H_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20H_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20I_ADM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20I_TRT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C20I_DIS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT CONDUCT TESTS"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C21       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C22_NO    -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX"
                       -4 "NOT MASTER FACILITY" ;
label define C22_UNIT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX"
                       -4 "NOT MASTER FACILITY" 1 "PER DAY" 2 "PER WEEK"
                       3 "PER MONTH" 4 "PER YEAR" ;
label define C23       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C24       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C25       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define C26       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - BLANK OR C25 NOT CODED 1"
                       -4 "NOT MASTER FACILITY" 1 "PROGRAMS SPECIFIED" ;
label define C27A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27F      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27G      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27H      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27I      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27J      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27K      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define C27L      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "YES, BY REFERRAL"
                       3 "NO" ;
label define D1_BOX    -4 "NOT MASTER FACILITY"
                       0 "BLANK, IMPLICITLY CAN EXCLUDE ALCOHOL CLIENTS"
                       1 "ALCOHOL ONLY CLIENTS COULD NOT BE EXCLUDED" ;
label define HIDD_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER HIDD"
                       -4 "NOT MASTER FACILITY" ;
label define HIDF_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER HIDF"
                       -4 "NOT MASTER FACILITY" ;
label define RSDD_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER RSDD"
                       -4 "NOT MASTER FACILITY" ;
label define RSDF_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER RSDF"
                       -4 "NOT MASTER FACILITY" ;
label define OPDD_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER OPDD"
                       -4 "NOT MASTER FACILITY" ;
label define OPDM_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER OPDM"
                       -4 "NOT MASTER FACILITY" ;
label define OPDF_D1   -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - SRV UNIT DID NOT OFFER OPDF"
                       -4 "NOT MASTER FACILITY" ;
label define TOTAL_D1  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D2        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY"
                       1 "ACTUAL NUMBERS FROM RECORDS"
                       2 "ESTIMATED NUMBERS FROM RECORDS" 3 "BEST GUESS"
                       4 "ACTUAL NUMBERS FROM AUTOMATED SYSTEM"
                       5 "ESTIMATED NUMBERS FROM AUTOMATED SYSTEM"
                       6 "OTHER (SPECIFY)" ;
label define FLAG17_A  -4 "NOT MASTER FACILITY" 0 "VARIABLE WAS NOT IMPUTED"
                       1 "VARIABLE WAS IMPUTED USING THE HOT DECK METHOD WITH"
                       2 "VARIABLE WAS MANUALLY ASSIGNED BASED ON OTHER"
                       3 "VARIABLE WAS IMPUTED USING A STRAIGHT HOT DECK METHOD"
                       4 "VARIABLE WAS IMPUTED FROM NDATUS EITHER USING A FACTOR"
                       5 "VARIABLE WAS ASSIGNED AS THE DIFFERENCE BETWEEN A TOTAL AND"
                       6 "A TOTAL OR SUBTOTAL WAS RECALCULATED BECAUSE THE SUM OF"
                       7 "A TOTAL WAS ASSIGNED THE SUMMING OF ALL THE PARTS, IF THEY"
                       8 "VARIABLE WAS IMPUTED FROM B1 TOTAL ACTUAL BASED ON THE"
                       9 "VARIABLE WAS IMPUTED FROM C1 COLUMN A TOTAL BASED ON" ;
label define D3        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" 1 "YES" 2 "NO" ;
label define D4        -7 "REFUSED" -5 "INAP - NOT CERTIFIED BY MEDICAID"
                       -4 "NOT MASTER FACILITY" ;
label define D5        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -5 "INAP - NOT CERTIFIED BY MEDICAID"
                       -4 "NOT MASTER FACILITY" ;
label define D6        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7B       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7C       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7D       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7E       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7F       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7G       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7H       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7I       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7J       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7K       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define D7L       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" -7 "REFUSED"
                       -4 "NOT MASTER FACILITY" ;
label define KEYBATCH  -4 "NOT MASTER FACILITY" ;
label define FLAG18_A  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_B  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_C  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_D  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_E  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_F  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_G  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_H  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_I  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_J  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_K  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_L  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define FLAG18_M  -4 "NOT MASTER FACILITY" 0 "NOT IMPUTED"
                       1 "HOT DECK - PROPORTIONAL ASSIGNMENT"
                       2 "MANUAL RECALCULATION BASED ON VARS IN SAME REC"
                       3 "HOT DECK - TRADITIONAL SUBSTITUTION"
                       4 "IMPUTED FROM NDATUS"
                       5 "IMPUTED BASED ON OTHER VARS IN SAME REC"
                       6 "TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION"
                       7 "TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS"
                       8 "B1 RATIO IMPUTATION BASED ON DONOR PATTERN"
                       9 "C1 RATIO IMPUTATION BASED ON DONOR PATTERN" ;
label define NFINWT0   -4.000000 "NOT MASTER FACILITY" ;
label define RPWT1     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT2     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT3     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT4     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT5     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT6     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT7     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT8     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT9     -4.000000 "NOT MASTER FACILITY" ;
label define RPWT10    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT11    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT12    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT13    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT14    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT15    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT16    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT17    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT18    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT19    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT20    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT21    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT22    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT23    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT24    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT25    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT26    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT27    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT28    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT29    -4.000000 "NOT MASTER FACILITY" ;
label define RPWT30    -4.000000 "NOT MASTER FACILITY" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace OBS_NUM = . if (OBS_NUM <= -1 )
replace CRP_MO1 = . if (CRP_MO1 <= -1 )
replace CRP_DA1 = . if (CRP_DA1 <= -1 )
replace CRP_YR1 = . if (CRP_YR1 <= -1 )
replace CRP_MO2 = . if (CRP_MO2 <= -1 )
replace CRP_DA2 = . if (CRP_DA2 <= -1 )
replace CRP_YR2 = . if (CRP_YR2 <= -1 )
replace CLENGTH = . if (CLENGTH <= -1 )
replace FRP_MO1 = . if (FRP_MO1 <= -1 )
replace FRP_DA1 = . if (FRP_DA1 <= -1 )
replace FRP_YR1 = . if (FRP_YR1 <= -1 )
replace FRP_MO2 = . if (FRP_MO2 <= -1 )
replace FRP_DA2 = . if (FRP_DA2 <= -1 )
replace FRP_YR2 = . if (FRP_YR2 <= -1 )
replace FLENGTH = . if (FLENGTH <= -1 )
replace A1_NO = . if (A1_NO <= -1 )
replace A1_UNIT = . if (A1_UNIT <= -1 )
replace A2A = . if (A2A <= -1 )
replace A2B = . if (A2B <= -1 )
replace A2C = . if (A2C <= -1 )
replace A2D = . if (A2D <= -1 )
replace A2E = . if (A2E <= -1 )
replace A3A = . if (A3A <= -1 )
replace A3B = . if (A3B <= -1 )
replace A3C = . if (A3C <= -1 )
replace A3D = . if (A3D <= -1 )
replace A3E = . if (A3E <= -1 )
replace A4A = . if (A4A <= -1 )
replace A4B = . if (A4B <= -1 )
replace A4C = . if (A4C <= -1 )
replace A4D = . if (A4D <= -1 )
replace A4E = . if (A4E <= -1 )
replace A4F = . if (A4F <= -1 )
replace A5A = . if (A5A <= -1 )
replace A5B = . if (A5B <= -1 )
replace HIDD_A6 = . if (HIDD_A6 <= -1 )
replace HIDM_A6 = . if (HIDM_A6 <= -1 )
replace HIDF_A6 = . if (HIDF_A6 <= -1 )
replace RSDD_A6 = . if (RSDD_A6 <= -1 )
replace RSDM_A6 = . if (RSDM_A6 <= -1 )
replace RSDF_A6 = . if (RSDF_A6 <= -1 )
replace OPDD_A6 = . if (OPDD_A6 <= -1 )
replace OPDM_A6 = . if (OPDM_A6 <= -1 )
replace OPDF_A6 = . if (OPDF_A6 <= -1 )
replace ALC_A6 = . if (ALC_A6 <= -1 )
replace CORRFAC = . if (CORRFAC <= -1 )
replace ALCHONLY = . if (ALCHONLY <= -1 )
replace SEQ11CNT = . if (SEQ11CNT <= -1 )
replace SEQ12CNT = . if (SEQ12CNT <= -1 )
replace NUMMOD = . if (NUMMOD <= -1 )
replace MOD = . if (MOD <= -1 )
replace OWN = . if (OWN <= -1 )
replace ENV = . if (ENV <= -1 )
replace XENV = . if (XENV <= -1 )
replace STRATUM = . if (STRATUM <= -1 )
replace REGION = . if (REGION <= -1 )
replace IMPFLAG = . if (IMPFLAG <= -1 )
replace A7_BOX = . if (A7_BOX <= -1 )
replace A7A_FT = . if (A7A_FT <= -1 )
replace A7A_PT = . if (A7A_PT <= -1 )
replace A7A_CON = . if (A7A_CON <= -1 )
replace A7A_CERT = . if (A7A_CERT <= -1 )
replace A7B_FT = . if (A7B_FT <= -1 )
replace A7B_PT = . if (A7B_PT <= -1 )
replace A7B_CON = . if (A7B_CON <= -1 )
replace A7B_CERT = . if (A7B_CERT <= -1 )
replace A7C_FT = . if (A7C_FT <= -1 )
replace A7C_PT = . if (A7C_PT <= -1 )
replace A7C_CON = . if (A7C_CON <= -1 )
replace A7C_CERT = . if (A7C_CERT <= -1 )
replace A7D_FT = . if (A7D_FT <= -1 )
replace A7D_PT = . if (A7D_PT <= -1 )
replace A7D_CON = . if (A7D_CON <= -1 )
replace A7D_CERT = . if (A7D_CERT <= -1 )
replace A7E_FT = . if (A7E_FT <= -1 )
replace A7E_PT = . if (A7E_PT <= -1 )
replace A7E_CON = . if (A7E_CON <= -1 )
replace A7E_CERT = . if (A7E_CERT <= -1 )
replace A7F_FT = . if (A7F_FT <= -1 )
replace A7F_PT = . if (A7F_PT <= -1 )
replace A7F_CON = . if (A7F_CON <= -1 )
replace A7F_CERT = . if (A7F_CERT <= -1 )
replace A7G_FT = . if (A7G_FT <= -1 )
replace A7G_PT = . if (A7G_PT <= -1 )
replace A7G_CON = . if (A7G_CON <= -1 )
replace A7G_CERT = . if (A7G_CERT <= -1 )
replace A7H_FT = . if (A7H_FT <= -1 )
replace A7H_PT = . if (A7H_PT <= -1 )
replace A7H_CON = . if (A7H_CON <= -1 )
replace A7H_CERT = . if (A7H_CERT <= -1 )
replace A7I_FT = . if (A7I_FT <= -1 )
replace A7I_PT = . if (A7I_PT <= -1 )
replace A7I_CON = . if (A7I_CON <= -1 )
replace A7I_CERT = . if (A7I_CERT <= -1 )
replace A7J_FT = . if (A7J_FT <= -1 )
replace A7J_PT = . if (A7J_PT <= -1 )
replace A7J_CON = . if (A7J_CON <= -1 )
replace A7J_CERT = . if (A7J_CERT <= -1 )
replace A7K_FT = . if (A7K_FT <= -1 )
replace A7K_PT = . if (A7K_PT <= -1 )
replace A7K_CON = . if (A7K_CON <= -1 )
replace A7K_CERT = . if (A7K_CERT <= -1 )
replace A7L_FT = . if (A7L_FT <= -1 )
replace A7L_PT = . if (A7L_PT <= -1 )
replace A7L_CON = . if (A7L_CON <= -1 )
replace A7L_CERT = . if (A7L_CERT <= -1 )
replace A7M_FT = . if (A7M_FT <= -1 )
replace A7M_PT = . if (A7M_PT <= -1 )
replace A7M_CON = . if (A7M_CON <= -1 )
replace A7M_CERT = . if (A7M_CERT <= -1 )
replace A8 = . if (A8 <= -1 )
replace A9 = . if (A9 <= -1 )
replace A10 = . if (A10 <= -1 )
replace A11 = . if (A11 <= -1 )
replace B1_BOX = . if (B1_BOX <= -1 )
replace HIDDMCAP = . if (HIDDMCAP <= -1 )
replace HIDDFCAP = . if (HIDDFCAP <= -1 )
replace HIDDTCAP = . if (HIDDTCAP <= -1 )
replace HIDDMACT = . if (HIDDMACT <= -1 )
replace HIDDFACT = . if (HIDDFACT <= -1 )
replace HIDDTACT = . if (HIDDTACT <= -1 )
replace HIDFMCAP = . if (HIDFMCAP <= -1 )
replace HIDFFCAP = . if (HIDFFCAP <= -1 )
replace HIDFTCAP = . if (HIDFTCAP <= -1 )
replace HIDFMACT = . if (HIDFMACT <= -1 )
replace HIDFFACT = . if (HIDFFACT <= -1 )
replace HIDFTACT = . if (HIDFTACT <= -1 )
replace RSDDMCAP = . if (RSDDMCAP <= -1 )
replace RSDDFCAP = . if (RSDDFCAP <= -1 )
replace RSDDTCAP = . if (RSDDTCAP <= -1 )
replace RSDDMACT = . if (RSDDMACT <= -1 )
replace RSDDFACT = . if (RSDDFACT <= -1 )
replace RSDDTACT = . if (RSDDTACT <= -1 )
replace RSDFMCAP = . if (RSDFMCAP <= -1 )
replace RSDFFCAP = . if (RSDFFCAP <= -1 )
replace RSDFTCAP = . if (RSDFTCAP <= -1 )
replace RSDFMACT = . if (RSDFMACT <= -1 )
replace RSDFFACT = . if (RSDFFACT <= -1 )
replace RSDFTACT = . if (RSDFTACT <= -1 )
replace FLAG4_A = . if (FLAG4_A <= -1 )
replace FLAG4_B = . if (FLAG4_B <= -1 )
replace FLAG4_C = . if (FLAG4_C <= -1 )
replace FLAG4_D = . if (FLAG4_D <= -1 )
replace FLAG4_E = . if (FLAG4_E <= -1 )
replace FLAG4_F = . if (FLAG4_F <= -1 )
replace FLAG4_G = . if (FLAG4_G <= -1 )
replace FLAG4_H = . if (FLAG4_H <= -1 )
replace FLAG4_I = . if (FLAG4_I <= -1 )
replace FLAG4_J = . if (FLAG4_J <= -1 )
replace FLAG4_K = . if (FLAG4_K <= -1 )
replace FLAG4_L = . if (FLAG4_L <= -1 )
replace FLAG4_M = . if (FLAG4_M <= -1 )
replace FLAG4_N = . if (FLAG4_N <= -1 )
replace FLAG4_O = . if (FLAG4_O <= -1 )
replace FLAG4_P = . if (FLAG4_P <= -1 )
replace OPDDMCAP = . if (OPDDMCAP <= -1 )
replace OPDDFCAP = . if (OPDDFCAP <= -1 )
replace OPDDTCAP = . if (OPDDTCAP <= -1 )
replace OPDDMACT = . if (OPDDMACT <= -1 )
replace OPDDFACT = . if (OPDDFACT <= -1 )
replace OPDDTACT = . if (OPDDTACT <= -1 )
replace OPDMMCAP = . if (OPDMMCAP <= -1 )
replace OPDMFCAP = . if (OPDMFCAP <= -1 )
replace OPDMTCAP = . if (OPDMTCAP <= -1 )
replace OPDMMACT = . if (OPDMMACT <= -1 )
replace OPDMFACT = . if (OPDMFACT <= -1 )
replace OPDMTACT = . if (OPDMTACT <= -1 )
replace OPDFMCAP = . if (OPDFMCAP <= -1 )
replace OPDFFCAP = . if (OPDFFCAP <= -1 )
replace OPDFTCAP = . if (OPDFTCAP <= -1 )
replace OPDFMACT = . if (OPDFMACT <= -1 )
replace OPDFFACT = . if (OPDFFACT <= -1 )
replace OPDFTACT = . if (OPDFTACT <= -1 )
replace FLAG5_A = . if (FLAG5_A <= -1 )
replace FLAG5_B = . if (FLAG5_B <= -1 )
replace FLAG5_C = . if (FLAG5_C <= -1 )
replace FLAG5_D = . if (FLAG5_D <= -1 )
replace FLAG5_E = . if (FLAG5_E <= -1 )
replace FLAG5_F = . if (FLAG5_F <= -1 )
replace FLAG5_G = . if (FLAG5_G <= -1 )
replace FLAG5_H = . if (FLAG5_H <= -1 )
replace FLAG5_I = . if (FLAG5_I <= -1 )
replace FLAG5_J = . if (FLAG5_J <= -1 )
replace FLAG5_K = . if (FLAG5_K <= -1 )
replace FLAG5_L = . if (FLAG5_L <= -1 )
replace ALCMCAP = . if (ALCMCAP <= -1 )
replace ALCFCAP = . if (ALCFCAP <= -1 )
replace ALCTCAP = . if (ALCTCAP <= -1 )
replace ALCMACT = . if (ALCMACT <= -1 )
replace ALCFACT = . if (ALCFACT <= -1 )
replace ALCTACT = . if (ALCTACT <= -1 )
replace TOTMCAP = . if (TOTMCAP <= -1 )
replace TOTFCAP = . if (TOTFCAP <= -1 )
replace TOTALCAP = . if (TOTALCAP <= -1 )
replace TOTMACT = . if (TOTMACT <= -1 )
replace TOTFACT = . if (TOTFACT <= -1 )
replace TOTALACT = . if (TOTALACT <= -1 )
replace B2 = . if (B2 <= -1 )
replace B3 = . if (B3 <= -1 )
replace B4_NO = . if (B4_NO <= -1 )
replace B4_UNIT = . if (B4_UNIT <= -1 )
replace B5 = . if (B5 <= -1 )
replace B6 = . if (B6 <= -1 )
replace B7 = . if (B7 <= -1 )
replace B8 = . if (B8 <= -1 )
replace B9A = . if (B9A <= -1 )
replace B9B = . if (B9B <= -1 )
replace WAITTIME = . if (WAITTIME <= -1.00 )
replace FLAG6_A = . if (FLAG6_A <= -1 )
replace FLAG6_B = . if (FLAG6_B <= -1 )
replace FLAG6_C = . if (FLAG6_C <= -1 )
replace FLAG6_D = . if (FLAG6_D <= -1 )
replace FLAG6_E = . if (FLAG6_E <= -1 )
replace FLAG6_F = . if (FLAG6_F <= -1 )
replace FLAG6_G = . if (FLAG6_G <= -1 )
replace FLAG6_H = . if (FLAG6_H <= -1 )
replace B10_BOX = . if (B10_BOX <= -1 )
replace HIDD_A = . if (HIDD_A <= -1 )
replace HIDD_B = . if (HIDD_B <= -1 )
replace HIDD_C = . if (HIDD_C <= -1 )
replace HIDD_D = . if (HIDD_D <= -1 )
replace HIDD_E = . if (HIDD_E <= -1 )
replace HIDF_A = . if (HIDF_A <= -1 )
replace HIDF_B = . if (HIDF_B <= -1 )
replace HIDF_C = . if (HIDF_C <= -1 )
replace HIDF_D = . if (HIDF_D <= -1 )
replace HIDF_E = . if (HIDF_E <= -1 )
replace RSDD_A = . if (RSDD_A <= -1 )
replace RSDD_B = . if (RSDD_B <= -1 )
replace RSDD_C = . if (RSDD_C <= -1 )
replace RSDD_D = . if (RSDD_D <= -1 )
replace RSDD_E = . if (RSDD_E <= -1 )
replace RSDF_A = . if (RSDF_A <= -1 )
replace RSDF_B = . if (RSDF_B <= -1 )
replace RSDF_C = . if (RSDF_C <= -1 )
replace RSDF_D = . if (RSDF_D <= -1 )
replace RSDF_E = . if (RSDF_E <= -1 )
replace OPDD_A = . if (OPDD_A <= -1 )
replace OPDD_B = . if (OPDD_B <= -1 )
replace OPDD_C = . if (OPDD_C <= -1 )
replace OPDD_D = . if (OPDD_D <= -1 )
replace OPDD_E = . if (OPDD_E <= -1 )
replace OPDM_A = . if (OPDM_A <= -1 )
replace OPDM_B = . if (OPDM_B <= -1 )
replace OPDM_C = . if (OPDM_C <= -1 )
replace OPDM_D = . if (OPDM_D <= -1 )
replace OPDM_E = . if (OPDM_E <= -1 )
replace OPDF_A = . if (OPDF_A <= -1 )
replace OPDF_B = . if (OPDF_B <= -1 )
replace OPDF_C = . if (OPDF_C <= -1 )
replace OPDF_D = . if (OPDF_D <= -1 )
replace OPDF_E = . if (OPDF_E <= -1 )
replace TOTAL_A = . if (TOTAL_A <= -1 )
replace TOTAL_B = . if (TOTAL_B <= -1 )
replace TOTAL_C = . if (TOTAL_C <= -1 )
replace TOTAL_D = . if (TOTAL_D <= -1 )
replace TOTAL_E = . if (TOTAL_E <= -1 )
replace B11 = . if (B11 <= -1 )
replace B12A = . if (B12A <= -1 )
replace B12B = . if (B12B <= -1 )
replace B12C = . if (B12C <= -1 )
replace B12D = . if (B12D <= -1 )
replace B12E = . if (B12E <= -1 )
replace B12F = . if (B12F <= -1 )
replace B12G = . if (B12G <= -1 )
replace B12H = . if (B12H <= -1 )
replace B12I = . if (B12I <= -1 )
replace B12J = . if (B12J <= -1 )
replace B13A = . if (B13A <= -1 )
replace B13B = . if (B13B <= -1 )
replace B13C = . if (B13C <= -1 )
replace B13D = . if (B13D <= -1 )
replace B13E = . if (B13E <= -1 )
replace B13F = . if (B13F <= -1 )
replace B13G = . if (B13G <= -1 )
replace B13H = . if (B13H <= -1 )
replace B13I = . if (B13I <= -1 )
replace B14 = . if (B14 <= -1 )
replace B15A = . if (B15A <= -1 )
replace B15B = . if (B15B <= -1 )
replace B15C = . if (B15C <= -1 )
replace B15D = . if (B15D <= -1 )
replace B15E = . if (B15E <= -1 )
replace B16 = . if (B16 <= -1 )
replace B17 = . if (B17 <= -1 )
replace B18 = . if (B18 <= -1 )
replace FLAG9_A = . if (FLAG9_A <= -1 )
replace FLAG9_B = . if (FLAG9_B <= -1 )
replace FLAG9_C = . if (FLAG9_C <= -1 )
replace FLAG9_D = . if (FLAG9_D <= -1 )
replace FLAG9_E = . if (FLAG9_E <= -1 )
replace FLAG9_F = . if (FLAG9_F <= -1 )
replace FLAG9_G = . if (FLAG9_G <= -1 )
replace FLAG9_H = . if (FLAG9_H <= -1 )
replace FLAG9_I = . if (FLAG9_I <= -1 )
replace FLAG9_J = . if (FLAG9_J <= -1 )
replace FLAG9_K = . if (FLAG9_K <= -1 )
replace FLAG9_L = . if (FLAG9_L <= -1 )
replace FLAG9_M = . if (FLAG9_M <= -1 )
replace FLAG9_N = . if (FLAG9_N <= -1 )
replace FLAG9_O = . if (FLAG9_O <= -1 )
replace FLAG9_P = . if (FLAG9_P <= -1 )
replace B19 = . if (B19 <= -1 )
replace B20A = . if (B20A <= -1 )
replace B20B = . if (B20B <= -1 )
replace B21 = . if (B21 <= -1 )
replace B22 = . if (B22 <= -1 )
replace B23 = . if (B23 <= -1 )
replace B24A = . if (B24A <= -1 )
replace B24B = . if (B24B <= -1 )
replace B24C = . if (B24C <= -1 )
replace B24D = . if (B24D <= -1 )
replace B24E = . if (B24E <= -1 )
replace B25 = . if (B25 <= -1 )
replace B25A = . if (B25A <= -1 )
replace B25B = . if (B25B <= -1 )
replace B25C = . if (B25C <= -1 )
replace B25D = . if (B25D <= -1 )
replace B25E = . if (B25E <= -1 )
replace B25F = . if (B25F <= -1 )
replace B25G = . if (B25G <= -1 )
replace B25H = . if (B25H <= -1 )
replace B26_NO = . if (B26_NO <= -1 )
replace B26_UNIT = . if (B26_UNIT <= -1 )
replace B27_NO = . if (B27_NO <= -1 )
replace B27_UNIT = . if (B27_UNIT <= -1 )
replace B28A = . if (B28A <= -1 )
replace B28B = . if (B28B <= -1 )
replace B28C = . if (B28C <= -1 )
replace B28D = . if (B28D <= -1 )
replace FLAG10_A = . if (FLAG10_A <= -1 )
replace FLAG10_B = . if (FLAG10_B <= -1 )
replace FLAG10_C = . if (FLAG10_C <= -1 )
replace FLAG10_D = . if (FLAG10_D <= -1 )
replace FLAG10_E = . if (FLAG10_E <= -1 )
replace FLAG10_F = . if (FLAG10_F <= -1 )
replace FLAG10_G = . if (FLAG10_G <= -1 )
replace FLAG10_H = . if (FLAG10_H <= -1 )
replace FLAG10_I = . if (FLAG10_I <= -1 )
replace FLAG10_J = . if (FLAG10_J <= -1 )
replace FLAG10_K = . if (FLAG10_K <= -1 )
replace FLAG10_L = . if (FLAG10_L <= -1 )
replace SEQ11 = . if (SEQ11 <= -1 )
replace HIDD_DEM = . if (HIDD_DEM <= -1 )
replace HIDF_DEM = . if (HIDF_DEM <= -1 )
replace RSDD_DEM = . if (RSDD_DEM <= -1 )
replace RSDF_DEM = . if (RSDF_DEM <= -1 )
replace OPDD_DEM = . if (OPDD_DEM <= -1 )
replace OPDM_DEM = . if (OPDM_DEM <= -1 )
replace OPDF_DEM = . if (OPDF_DEM <= -1 )
replace ALC_DEM = . if (ALC_DEM <= -1 )
replace A_WHITE = . if (A_WHITE <= -1 )
replace A_BLACK = . if (A_BLACK <= -1 )
replace A_HISP = . if (A_HISP <= -1 )
replace A_ASIAN = . if (A_ASIAN <= -1 )
replace A_INDIAN = . if (A_INDIAN <= -1 )
replace A_OTHER = . if (A_OTHER <= -1 )
replace B_14 = . if (B_14 <= -1 )
replace B_15 = . if (B_15 <= -1 )
replace B_18 = . if (B_18 <= -1 )
replace B_25 = . if (B_25 <= -1 )
replace B_35 = . if (B_35 <= -1 )
replace B_45 = . if (B_45 <= -1 )
replace B_65 = . if (B_65 <= -1 )
replace C_EMP = . if (C_EMP <= -1 )
replace C_NOTEMP = . if (C_NOTEMP <= -1 )
replace DEMXENV2 = . if (DEMXENV2 <= -1 )
replace SEQ12 = . if (SEQ12 <= -1 )
replace D_HEROIN = . if (D_HEROIN <= -1 )
replace D_CRACK = . if (D_CRACK <= -1 )
replace D_COCAIN = . if (D_COCAIN <= -1 )
replace D_BENZ = . if (D_BENZ <= -1 )
replace D_BARB = . if (D_BARB <= -1 )
replace D_AMPH = . if (D_AMPH <= -1 )
replace D_MARIJ = . if (D_MARIJ <= -1 )
replace D_PCP = . if (D_PCP <= -1 )
replace D_OTH = . if (D_OTH <= -1 )
replace E_NOPAY = . if (E_NOPAY <= -1 )
replace E_SLFPAY = . if (E_SLFPAY <= -1 )
replace E_PRIVTE = . if (E_PRIVTE <= -1 )
replace E_MEDCD = . if (E_MEDCD <= -1 )
replace MEDCR_E = . if (MEDCR_E <= -1 )
replace E_OTHER = . if (E_OTHER <= -1 )
replace METHOD = . if (METHOD <= -1 )
replace C1_BOX = . if (C1_BOX <= -1 )
replace HIDD_C1A = . if (HIDD_C1A <= -1 )
replace HIDD_C1B = . if (HIDD_C1B <= -1 )
replace HIDD_C1C = . if (HIDD_C1C <= -1 )
replace HIDD_C1D = . if (HIDD_C1D <= -1 )
replace HIDD_C1E = . if (HIDD_C1E <= -1 )
replace HIDF_C1A = . if (HIDF_C1A <= -1 )
replace HIDF_C1B = . if (HIDF_C1B <= -1 )
replace HIDF_C1C = . if (HIDF_C1C <= -1 )
replace HIDF_C1D = . if (HIDF_C1D <= -1 )
replace HIDF_C1E = . if (HIDF_C1E <= -1 )
replace RSDD_C1A = . if (RSDD_C1A <= -1 )
replace RSDD_C1B = . if (RSDD_C1B <= -1 )
replace RSDD_C1C = . if (RSDD_C1C <= -1 )
replace RSDD_C1D = . if (RSDD_C1D <= -1 )
replace RSDD_C1E = . if (RSDD_C1E <= -1 )
replace RSDF_C1A = . if (RSDF_C1A <= -1 )
replace RSDF_C1B = . if (RSDF_C1B <= -1 )
replace RSDF_C1C = . if (RSDF_C1C <= -1 )
replace RSDF_C1D = . if (RSDF_C1D <= -1 )
replace RSDF_C1E = . if (RSDF_C1E <= -1 )
replace FLAG13_A = . if (FLAG13_A <= -1 )
replace FLAG13_B = . if (FLAG13_B <= -1 )
replace FLAG13_C = . if (FLAG13_C <= -1 )
replace FLAG13_D = . if (FLAG13_D <= -1 )
replace FLAG13_E = . if (FLAG13_E <= -1 )
replace FLAG13_F = . if (FLAG13_F <= -1 )
replace FLAG13_G = . if (FLAG13_G <= -1 )
replace FLAG13_H = . if (FLAG13_H <= -1 )
replace FLAG13_I = . if (FLAG13_I <= -1 )
replace FLAG13_J = . if (FLAG13_J <= -1 )
replace FLAG13_K = . if (FLAG13_K <= -1 )
replace FLAG13_L = . if (FLAG13_L <= -1 )
replace FLAG13_M = . if (FLAG13_M <= -1 )
replace FLAG13_N = . if (FLAG13_N <= -1 )
replace FLAG13_O = . if (FLAG13_O <= -1 )
replace FLAG13_P = . if (FLAG13_P <= -1 )
replace FLAG13_Q = . if (FLAG13_Q <= -1 )
replace FLAG13_R = . if (FLAG13_R <= -1 )
replace FLAG13_S = . if (FLAG13_S <= -1 )
replace FLAG13_T = . if (FLAG13_T <= -1 )
replace OPDD_C1A = . if (OPDD_C1A <= -1 )
replace OPDD_C1B = . if (OPDD_C1B <= -1 )
replace OPDD_C1C = . if (OPDD_C1C <= -1 )
replace OPDD_C1D = . if (OPDD_C1D <= -1 )
replace OPDD_C1E = . if (OPDD_C1E <= -1 )
replace OPDM_C1A = . if (OPDM_C1A <= -1 )
replace OPDM_C1B = . if (OPDM_C1B <= -1 )
replace OPDM_C1C = . if (OPDM_C1C <= -1 )
replace OPDM_C1D = . if (OPDM_C1D <= -1 )
replace OPDM_C1E = . if (OPDM_C1E <= -1 )
replace OPDF_C1A = . if (OPDF_C1A <= -1 )
replace OPDF_C1B = . if (OPDF_C1B <= -1 )
replace OPDF_C1C = . if (OPDF_C1C <= -1 )
replace OPDF_C1D = . if (OPDF_C1D <= -1 )
replace OPDF_C1E = . if (OPDF_C1E <= -1 )
replace TOT_C1A = . if (TOT_C1A <= -1 )
replace TOT_C1B = . if (TOT_C1B <= -1 )
replace TOT_C1C = . if (TOT_C1C <= -1 )
replace TOT_C1D = . if (TOT_C1D <= -1 )
replace TOT_C1E = . if (TOT_C1E <= -1 )
replace C2 = . if (C2 <= -1 )
replace FLAG14_A = . if (FLAG14_A <= -1 )
replace FLAG14_B = . if (FLAG14_B <= -1 )
replace FLAG14_C = . if (FLAG14_C <= -1 )
replace FLAG14_D = . if (FLAG14_D <= -1 )
replace FLAG14_E = . if (FLAG14_E <= -1 )
replace FLAG14_F = . if (FLAG14_F <= -1 )
replace FLAG14_G = . if (FLAG14_G <= -1 )
replace FLAG14_H = . if (FLAG14_H <= -1 )
replace FLAG14_I = . if (FLAG14_I <= -1 )
replace FLAG14_J = . if (FLAG14_J <= -1 )
replace FLAG14_K = . if (FLAG14_K <= -1 )
replace FLAG14_L = . if (FLAG14_L <= -1 )
replace FLAG14_M = . if (FLAG14_M <= -1 )
replace FLAG14_N = . if (FLAG14_N <= -1 )
replace FLAG14_O = . if (FLAG14_O <= -1 )
replace FLAG14_P = . if (FLAG14_P <= -1 )
replace FLAG14_Q = . if (FLAG14_Q <= -1 )
replace FLAG14_R = . if (FLAG14_R <= -1 )
replace FLAG14_S = . if (FLAG14_S <= -1 )
replace FLAG14_T = . if (FLAG14_T <= -1 )
replace HIDDPNO = . if (HIDDPNO <= -1 )
replace HIDDPUNT = . if (HIDDPUNT <= -1 )
replace HIDDANO = . if (HIDDANO <= -1 )
replace HIDDAUNT = . if (HIDDAUNT <= -1 )
replace HIDFPNO = . if (HIDFPNO <= -1 )
replace HIDFPUNT = . if (HIDFPUNT <= -1 )
replace HIDFANO = . if (HIDFANO <= -1 )
replace HIDFAUNT = . if (HIDFAUNT <= -1 )
replace RSDDPNO = . if (RSDDPNO <= -1 )
replace RSDDPUNT = . if (RSDDPUNT <= -1 )
replace RSDDANO = . if (RSDDANO <= -1 )
replace RSDDAUNT = . if (RSDDAUNT <= -1 )
replace RSDFPNO = . if (RSDFPNO <= -1 )
replace RSDFPUNT = . if (RSDFPUNT <= -1 )
replace RSDFANO = . if (RSDFANO <= -1 )
replace RSDFAUNT = . if (RSDFAUNT <= -1 )
replace OPDDPNO = . if (OPDDPNO <= -1 )
replace OPDDPUNT = . if (OPDDPUNT <= -1 )
replace OPDDANO = . if (OPDDANO <= -1 )
replace OPDDAUNT = . if (OPDDAUNT <= -1 )
replace OPDMPNO = . if (OPDMPNO <= -1 )
replace OPDMPUNT = . if (OPDMPUNT <= -1 )
replace OPDMANO = . if (OPDMANO <= -1 )
replace OPDMAUNT = . if (OPDMAUNT <= -1 )
replace OPDFPNO = . if (OPDFPNO <= -1 )
replace OPDFPUNT = . if (OPDFPUNT <= -1 )
replace OPDFANO = . if (OPDFANO <= -1 )
replace OPDFAUNT = . if (OPDFAUNT <= -1 )
replace C4 = . if (C4 <= -1 )
replace C5 = . if (C5 <= -1 )
replace C6 = . if (C6 <= -1 )
replace C7A = . if (C7A <= -1 )
replace C7B = . if (C7B <= -1 )
replace C7C = . if (C7C <= -1 )
replace C7D = . if (C7D <= -1 )
replace C7E = . if (C7E <= -1 )
replace C7F = . if (C7F <= -1 )
replace C7G = . if (C7G <= -1 )
replace C7H = . if (C7H <= -1 )
replace C7I = . if (C7I <= -1 )
replace C7J = . if (C7J <= -1 )
replace C8A = . if (C8A <= -1 )
replace C8B = . if (C8B <= -1 )
replace C8C = . if (C8C <= -1 )
replace C8D = . if (C8D <= -1 )
replace C9 = . if (C9 <= -1 )
replace C10_REF = . if (C10_REF <= -1 )
replace C11_REF = . if (C11_REF <= -1 )
replace C12_TST = . if (C12_TST <= -1 )
replace C13 = . if (C13 <= -1 )
replace C14 = . if (C14 <= -1 )
replace C16 = . if (C16 <= -1 )
replace C17 = . if (C17 <= -1 )
replace C18A = . if (C18A <= -1 )
replace C18B = . if (C18B <= -1 )
replace C18C = . if (C18C <= -1 )
replace C19A = . if (C19A <= -1 )
replace C19B = . if (C19B <= -1 )
replace C19C = . if (C19C <= -1 )
replace C20A_ADM = . if (C20A_ADM <= -1 )
replace C20A_TRT = . if (C20A_TRT <= -1 )
replace C20A_DIS = . if (C20A_DIS <= -1 )
replace C20B_ADM = . if (C20B_ADM <= -1 )
replace C20B_TRT = . if (C20B_TRT <= -1 )
replace C20B_DIS = . if (C20B_DIS <= -1 )
replace C20C_ADM = . if (C20C_ADM <= -1 )
replace C20C_TRT = . if (C20C_TRT <= -1 )
replace C20C_DIS = . if (C20C_DIS <= -1 )
replace C20D_ADM = . if (C20D_ADM <= -1 )
replace C20D_TRT = . if (C20D_TRT <= -1 )
replace C20D_DIS = . if (C20D_DIS <= -1 )
replace C20E_ADM = . if (C20E_ADM <= -1 )
replace C20E_TRT = . if (C20E_TRT <= -1 )
replace C20E_DIS = . if (C20E_DIS <= -1 )
replace C20F_ADM = . if (C20F_ADM <= -1 )
replace C20F_TRT = . if (C20F_TRT <= -1 )
replace C20F_DIS = . if (C20F_DIS <= -1 )
replace C20G_ADM = . if (C20G_ADM <= -1 )
replace C20G_TRT = . if (C20G_TRT <= -1 )
replace C20G_DIS = . if (C20G_DIS <= -1 )
replace C20H_ADM = . if (C20H_ADM <= -1 )
replace C20H_TRT = . if (C20H_TRT <= -1 )
replace C20H_DIS = . if (C20H_DIS <= -1 )
replace C20I_ADM = . if (C20I_ADM <= -1 )
replace C20I_TRT = . if (C20I_TRT <= -1 )
replace C20I_DIS = . if (C20I_DIS <= -1 )
replace C21 = . if (C21 <= -1 )
replace C22_NO = . if (C22_NO <= -1 )
replace C22_UNIT = . if (C22_UNIT <= -1 )
replace C23 = . if (C23 <= -1 )
replace C24 = . if (C24 <= -1 )
replace C25 = . if (C25 <= -1 )
replace C26 = . if (C26 <= -1 )
replace C27A = . if (C27A <= -1 )
replace C27B = . if (C27B <= -1 )
replace C27C = . if (C27C <= -1 )
replace C27D = . if (C27D <= -1 )
replace C27E = . if (C27E <= -1 )
replace C27F = . if (C27F <= -1 )
replace C27G = . if (C27G <= -1 )
replace C27H = . if (C27H <= -1 )
replace C27I = . if (C27I <= -1 )
replace C27J = . if (C27J <= -1 )
replace C27K = . if (C27K <= -1 )
replace C27L = . if (C27L <= -1 )
replace D1_BOX = . if (D1_BOX <= -1 )
replace HIDD_D1 = . if (HIDD_D1 <= -1 )
replace HIDF_D1 = . if (HIDF_D1 <= -1 )
replace RSDD_D1 = . if (RSDD_D1 <= -1 )
replace RSDF_D1 = . if (RSDF_D1 <= -1 )
replace OPDD_D1 = . if (OPDD_D1 <= -1 )
replace OPDM_D1 = . if (OPDM_D1 <= -1 )
replace OPDF_D1 = . if (OPDF_D1 <= -1 )
replace TOTAL_D1 = . if (TOTAL_D1 <= -1 )
replace D2 = . if (D2 <= -1 )
replace FLAG17_A = . if (FLAG17_A <= -1 )
replace D3 = . if (D3 <= -1 )
replace D4 = . if (D4 <= -1 )
replace D5 = . if (D5 <= -1 )
replace D6 = . if (D6 <= -1 )
replace D7A = . if (D7A <= -1 )
replace D7B = . if (D7B <= -1 )
replace D7C = . if (D7C <= -1 )
replace D7D = . if (D7D <= -1 )
replace D7E = . if (D7E <= -1 )
replace D7F = . if (D7F <= -1 )
replace D7G = . if (D7G <= -1 )
replace D7H = . if (D7H <= -1 )
replace D7I = . if (D7I <= -1 )
replace D7J = . if (D7J <= -1 )
replace D7K = . if (D7K <= -1 )
replace D7L = . if (D7L <= -1 )
replace KEYBATCH = . if (KEYBATCH <= -1 )
replace FLAG18_A = . if (FLAG18_A <= -1 )
replace FLAG18_B = . if (FLAG18_B <= -1 )
replace FLAG18_C = . if (FLAG18_C <= -1 )
replace FLAG18_D = . if (FLAG18_D <= -1 )
replace FLAG18_E = . if (FLAG18_E <= -1 )
replace FLAG18_F = . if (FLAG18_F <= -1 )
replace FLAG18_G = . if (FLAG18_G <= -1 )
replace FLAG18_H = . if (FLAG18_H <= -1 )
replace FLAG18_I = . if (FLAG18_I <= -1 )
replace FLAG18_J = . if (FLAG18_J <= -1 )
replace FLAG18_K = . if (FLAG18_K <= -1 )
replace FLAG18_L = . if (FLAG18_L <= -1 )
replace FLAG18_M = . if (FLAG18_M <= -1 )
replace NFINWT0 = . if (NFINWT0 <= -1.000000 )
replace RPWT1 = . if (RPWT1 <= -1.000000 )
replace RPWT2 = . if (RPWT2 <= -1.000000 )
replace RPWT3 = . if (RPWT3 <= -1.000000 )
replace RPWT4 = . if (RPWT4 <= -1.000000 )
replace RPWT5 = . if (RPWT5 <= -1.000000 )
replace RPWT6 = . if (RPWT6 <= -1.000000 )
replace RPWT7 = . if (RPWT7 <= -1.000000 )
replace RPWT8 = . if (RPWT8 <= -1.000000 )
replace RPWT9 = . if (RPWT9 <= -1.000000 )
replace RPWT10 = . if (RPWT10 <= -1.000000 )
replace RPWT11 = . if (RPWT11 <= -1.000000 )
replace RPWT12 = . if (RPWT12 <= -1.000000 )
replace RPWT13 = . if (RPWT13 <= -1.000000 )
replace RPWT14 = . if (RPWT14 <= -1.000000 )
replace RPWT15 = . if (RPWT15 <= -1.000000 )
replace RPWT16 = . if (RPWT16 <= -1.000000 )
replace RPWT17 = . if (RPWT17 <= -1.000000 )
replace RPWT18 = . if (RPWT18 <= -1.000000 )
replace RPWT19 = . if (RPWT19 <= -1.000000 )
replace RPWT20 = . if (RPWT20 <= -1.000000 )
replace RPWT21 = . if (RPWT21 <= -1.000000 )
replace RPWT22 = . if (RPWT22 <= -1.000000 )
replace RPWT23 = . if (RPWT23 <= -1.000000 )
replace RPWT24 = . if (RPWT24 <= -1.000000 )
replace RPWT25 = . if (RPWT25 <= -1.000000 )
replace RPWT26 = . if (RPWT26 <= -1.000000 )
replace RPWT27 = . if (RPWT27 <= -1.000000 )
replace RPWT28 = . if (RPWT28 <= -1.000000 )
replace RPWT29 = . if (RPWT29 <= -1.000000 )
replace RPWT30 = . if (RPWT30 <= -1.000000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

